/* Generated file (by generator) */

/*
 * Copyright (C) 2015 William Yu <williamyu@gnome.org>
 *
 * This library is free software: you can redistribute it and/or modify it
 * under the terms of version 2.1. of the GNU Lesser General Public License
 * as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library. If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef LIBICAL_GLIB_H
#define LIBICAL_GLIB_H

#include <glib-object.h>

#if !defined(LIBICAL_GLIB_UNSTABLE_API) && !defined(LIBICAL_GLIB_COMPILATION)
#error "Define LIBICAL_GLIB_UNSTABLE_API, to indicate it's understood the libical-glib API is currently unstable"
#endif

#define __LIBICAL_GLIB_H_INSIDE__

#include <libical-glib/i-cal-forward-declarations.h>
#include <libical-glib/i-cal-array.h>
#include <libical-glib/i-cal-attach.h>
#include <libical-glib/i-cal-comp-iter.h>
#include <libical-glib/i-cal-component.h>
#include <libical-glib/i-cal-datetimeperiod.h>
#include <libical-glib/i-cal-derived-parameter.h>
#include <libical-glib/i-cal-derived-property.h>
#include <libical-glib/i-cal-derived-value.h>
#include <libical-glib/i-cal-duration.h>
#include <libical-glib/i-cal-enums.h>
#include <libical-glib/i-cal-error.h>
#include <libical-glib/i-cal-geo.h>
#include <libical-glib/i-cal-memory.h>
#include <libical-glib/i-cal-mime.h>
#include <libical-glib/i-cal-parameter.h>
#include <libical-glib/i-cal-parser.h>
#include <libical-glib/i-cal-period.h>
#include <libical-glib/i-cal-property.h>
#include <libical-glib/i-cal-recur-iterator.h>
#include <libical-glib/i-cal-recur.h>
#include <libical-glib/i-cal-recurrence.h>
#include <libical-glib/i-cal-reqstat.h>
#include <libical-glib/i-cal-restriction.h>
#include <libical-glib/i-cal-time-span.h>
#include <libical-glib/i-cal-time.h>
#include <libical-glib/i-cal-timezone.h>
#include <libical-glib/i-cal-trigger.h>
#include <libical-glib/i-cal-unknowntokenhandling.h>
#include <libical-glib/i-cal-value.h>

#undef __LIBICAL_GLIB_H_INSIDE__

#endif /* LIBICAL_GLIB_H */
